@@ -27,7 +27,7 @@ from scullery import messagebus, workers, util
 
 try:
     import msgpack
-except:
+except Exception:
     pass
 
 logger = logging.getLogger("system.mqtt")
@@ -47,23 +47,18 @@ allSubscriptions = {}
 connectionsByBusName = weakref.WeakValueDictionary()
 
 
-def checkIfConnected(c, delay):
-    time.sleep(delay)
-    if not c.isConnected:
-        logging.warning("An MQTT connection to : " + str(c.server) + " was not connected after "+str(delay) + " seconds of waiting")
-
-
 def getWeakrefHandlers(self):
     self = weakref.ref(self)
 
     def on_connect(client, userdata=None, flags=None, rc=0, *a):
         if not rc == 0:
-            self().onDisconnected()
+            self().on_disconnected()
             return
 
-        logger.info("Connected to MQTT server: " +
-                    self().server + "result code " + str(rc))
-        self().onStillConnected()
+        logger.info(
+            "Connected to MQTT server: " + self().server + "result code " + str(rc)
+        )
+        self().on_still_connected()
         # Don't block the network thread too long
 
         def subscriptionRefresh():
@@ -75,25 +70,27 @@ def getWeakrefHandlers(self):
                             if allSubscriptions[i]():
                                 # Refresh all subscriptions
                                 self().connection.subscribe(i[1], i[2])
-            except:
+            except Exception:
                 logger.exception("Error subscription refresh")
+
         workers.do(subscriptionRefresh)
 
     def on_disconnect(client, *a):
         if not self():
             return
-        logger.info("Disconnected from MQTT server: " + self().server)
-        self().onDisconnected()
-        logger.info("Disconnected from MQTT server: " + self().server)
+        logger.info("Dis_connected from MQTT server: " + self().server)
+        self().on_disconnected()
+        logger.info("Dis_connected from MQTT server: " + self().server)
 
     def on_message(client, userdata, msg):
         try:
             s = self()
             # Everything must be fine, because we are getting messages
-            messagebus.postMessage(s.busPrefix + "/in/" + msg.topic,
-                                   msg.payload,
-                                   )
-            s.onStillConnected()
+            messagebus.post_message(
+                s.busPrefix + "/in/" + msg.topic,
+                msg.payload,
+            )
+            s.on_still_connected()
         except Exception:
             print(traceback.format_exc())
 
@@ -101,117 +98,33 @@ def getWeakrefHandlers(self):
 
 
 # Used to fake a crash fro unit testing purposes
-testCrashOnce = False
 
 
-def makeThread(c, ref):
-    def f2():
-        global testCrashOnce
-        try:
-            if testCrashOnce:
-                testCrashOnce = False
-                raise RuntimeError("Test crash once")
-            c.loop_forever(retry_first_connection=True)
-        except:
-            if ref():
-                ref().onConnectionCrash(traceback.format_exc())
-                logger.exception("MQTT Crash")
-
-    return f2
-
-
-class HBMQTTMessage():
-    pass
-
-
-class HBMQTTWrapper():
-    def __init__(self, manager_ref, client) -> None:
-        self.client = client
-        self.ref = manager_ref()
-        from hbmqtt.mqtt.constants import QOS_0, QOS_1, QOS_2
-        self.qosmap = {0: QOS_0, 1: QOS_1, 2: QOS_2}
-        # For connect_async
-        self.connectFunction = None
-
-    def subscribe(self, topic, qos=0):
-        @asyncio.coroutine
-        def f():
-            yield from self.client.subscribe([(topic, self.qosmap[qos])])
-
-        asyncio.get_event_loop().run_until_complete(f())
-
-    def unsubscribe(self, topic):
-        @asyncio.coroutine
-        def f():
-            yield from self.client.unsubscribe([topic])
-
-        asyncio.get_event_loop().run_until_complete(f())
-
-    def publish(self, topic, payload, qos=0, retain=False):
-        @asyncio.coroutine
-        def f():
-            yield from self.client.publish(topic, payload, self.qosmap[qos], retain)
-
-        asyncio.get_event_loop().run_until_complete(f())
-
-    def connect_async(self, host, port=1883, keepalive=60, bind_address=""):
-        def connectFunction():
-
-            @asyncio.coroutine
-            def f():
-                yield from self.client.connect(host + ":" + port)
-
-            asyncio.get_event_loop().run_until_complete(f())
-        self.connectFunction = connectFunction
-
-    def connect(self, host, port=1883, keepalive=60, bind_address=""):
-        self.connect_async(host, port, keepalive, bind_address)
-        self.connectFunction()
-
-    def loop_forever(timeout=1.0, max_packets=1, retry_first_connection=False):
-        if self.connectFunction:
-            self.connectFunction()
-
-    @asyncio.coroutine
-    def run(self):
-        r = self.ref
-        from hbmqtt.client import MQTTClient, ClientException
-
-        C = MQTTClient()
-        yield from C.connect(r().server + ':' + str(r().port))
-        self.connected = True
-        # Subscribe to '$SYS/broker/uptime' with QOS=1
-        # Subscribe to '$SYS/broker/load/#' with QOS=2
-        self.on_connect(self, None, None, None)
-
-        while r():
-
-            message = yield from C.deliver_message(timeout=3)
-            packet = message.publish_packet
-            msg = HBMQTTMessage
-            msg.payload = packet.payload.data
-            msg.packet.variable_header.topic_name
-            self.on_message(None, None, msg)
-
-        yield from C.disconnect()
-
-
-class Connection():
-    def __init__(self, server, port=1883, password=None, messageBusName=None, *, alertPriority="info", alertAck=True, connectionID=''):
-
-        # ConnectionID is used to ensure separate *physical* connections and prevent reuse
+class Connection:
+    def __init__(
+        self,
+        server,
+        port=1883,
+        password=None,
+        message_bus_name=None,
+        *,
+        alert_priority="info",
+        alert_ack=True,
+        connection_id=""
+    ):
+        # connection_id is used to ensure separate *physical* connections and prevent reuse
         self.server = server
         self.port = port
         self.lock = threading.Lock()
         self.password = password
 
-        self.messageBusName = messageBusName
+        self.message_bus_name = message_bus_name
         self.connection = None
 
-        #Defensive against None
-        connectionID = connectionID or ''
+        # Defensive against None
+        connection_id = connection_id or ""
 
-        self.isConnected = False
+        self.is_connected = False
 
         if not server:
             passive = True
@@ -223,10 +136,12 @@ class Connection():
         server = server or str(uuid.uuid4())
         virtual = server.startswith("__virtual__")
 
-        if passive and (not messageBusName):
+        if passive and (not message_bus_name):
             raise ValueError(
-                "No server specified. To create a passive connection you must specify an internal messageBusName")
-        self.busPrefix = "/mqtt/" + server + ":" + str(port) + (connectionID or '')
+                "No server specified. To create a passive connection you must specify an internal message_bus_name"
+            )
+        self.busPrefix = "/mqtt/" + server + \
+            ":" + str(port) + (connection_id or "")
 
         self.subscriptions = {}
         logger.info("Creating connection object to: " + self.server)
@@ -236,11 +151,13 @@ class Connection():
         # paho requires non-python stuff.
         try:
             import paho.mqtt.client as mqtt
+
             paho = True
 
         except ImportError:
             logging.exception(
-                "PahoMQTT not installed. No MQTT connection possible here. continuing with dummy.")
+                "PahoMQTT not installed. No MQTT connection possible here. continuing with dummy."
+            )
             paho = False
 
         # When we wrap a function store a weakref to the original here,
@@ -249,11 +166,11 @@ class Connection():
         self.subscribeWrappers = {}
 
         with lock:
-            if connectionID:
-                connectionID = '?' + connectionID
-            self.connectionID = connectionID
+            if connection_id:
+                connection_id = "?" + connection_id
+            self.connection_id = connection_id
 
-            n = server + ":" + str(port) + connectionID
+            n = server + ":" + str(port) + connection_id
             if n in connections and connections[n]():
                 raise RuntimeError("There is already a connection")
             torm = []
@@ -264,21 +181,26 @@ class Connection():
                 del connections[i]
             connections[n] = weakref.ref(self)
 
-            if messageBusName:
-                self.busPrefix = "/mqtt/" + messageBusName
+            if message_bus_name:
+                self.busPrefix = "/mqtt/" + message_bus_name
 
             try:
-
                 if not virtual and not passive:
+
                     def out_handler(topic, message, timestamp, annotation):
-                        self.connection.publish(topic[len(
-                            self.busPrefix + "/out/"):], payload=message, qos=annotation[0], retain=annotation[1])
+                        self.connection.publish(
+                            topic[len(self.busPrefix + "/out/"):],
+                            payload=message,
+                            qos=annotation[0],
+                            retain=annotation[1],
+                        )
+
                 else:
                     if not passive:
                         # Virtual loopback server doesn't actually use a real server
                         def out_handler(topic, message, timestamp, annotation):
                             t = topic[len(self.busPrefix + "/out/"):]
-                            messagebus.postMessage(
+                            messagebus.post_message(
                                 self.busPrefix + "/in/" + t, message)
 
                 if not passive:
@@ -302,55 +224,12 @@ class Connection():
                     self.username = user
                     self.password = password
 
-                    self.configureAlert(alertPriority, alertAck)
+                    self.configure_alert(alert_priority, alert_ack)
 
-                    if paho:
-                        # Ok so the connection is supposed to do this by itself. Some condition can
-                        # Cause the loop to crash and I do not know what!
-                        def reconnect():
-                            try:
-                                if self.connection:
-                                    self.connection.disconnect()
-                            except:
-                                pass
-
-                            self.connection = mqtt.Client()
-                            # We don't want the connection to stringly reference us, that would interfere with GC
-                            on_connect, on_disconnect, on_message = getWeakrefHandlers(
-                                self)
-
-                            if self.username:
-                                self.username_pw_set(
-                                    self.username, self.password)
-
-                            self.connection.connect_async(
-                                host, port=port, keepalive=60, bind_address="")
-
-                            self.connection.on_connect = on_connect
-                            self.connection.on_disconnect = on_disconnect
-                            self.connection.on_message = on_message
-
-                            self._thread = threading.Thread(target=makeThread(
-                                self.connection, weakref.ref(self)), name=server + ":" + str(port), daemon=True)
-                            self._thread.start()
-
-                    # Independant hbmqtt implementation
-                    else:
-                        raise RuntimeError(
-                            "Only Paho is supported at the moment")
-
-                    self.reconnect = reconnect
-
-                    # Actually do the connection.
-                    self.reconnect()
-                    # Give it 5 mins before we print a warning.
-                    def f():
-                        checkIfConnected(self,5)
-                    workers.do(f)
                 else:
                     self.connection = None
-                    self.configureAlert(alertPriority, alertAck)
-                    self.onStillConnected()
+                    self.configure_alert(alert_priority, alert_ack)
+                    self.on_still_connected()
 
                 if not passive:
                     connectionsByBusName[self.busPrefix] = self
@@ -368,24 +247,25 @@ class Connection():
                     pass
                 raise
 
-    def onConnectionCrash(self, tb):
+    def on_connection_crash(self, tb):
         print(traceback.format_exc())
         self.reconnect()
 
-    def onStillConnected(self):
-        if not self.isConnected:
-            messagebus.postMessage(self.localStatusTopic, "connected")
-        self.isConnected = True
+    def on_still_connected(self):
+        if not self.is_connected:
+            messagebus.post_message(self.localStatusTopic, "connected")
+        self.is_connected = True
         pass
 
-    def onDisconnected(self):
-        logging.warning("A connection has disconnected from MQTT server: " + self.server)
-        if self.isConnected:
-            messagebus.postMessage(self.localStatusTopic, "disconnected")
-        self.isConnected = False
-        
+    def on_disconnected(self):
+        logging.warning(
+            "A connection has dis_connected from MQTT server: " + self.server
+        )
+        if self.is_connected:
+            messagebus.post_message(self.localStatusTopic, "dis_connected")
+        self.is_connected = False
 
-    def subscribeToStatus(self, f):
+    def subscribe_to_status(self, f):
         messagebus.subscribe(self.localStatusTopic, f)
 
     def close(self):
@@ -396,7 +276,7 @@ class Connection():
             pass
         try:
             del connections[self.server + ":" +
-                            str(self.port) + self.connectionID]
+                            str(self.port) + self.connection_id]
         except Exception:
             pass
 
@@ -405,15 +285,17 @@ class Connection():
             self.connection.disconnect()
 
     def unsubscribe(self, topic, function):
-
         with self.lock:
-
             # Very expensive to search this dict like this, but unsub shouldn't happen much.
             try:
                 torm = []
                 # Find any subscriptions to the topic for this particular bus prefix and delete them
                 for i in allSubscriptions:
-                    if i[0] == self.busPrefix and i[1] == topic and allSubscriptions[i]() == function:
+                    if (
+                        i[0] == self.busPrefix
+                        and i[1] == topic
+                        and allSubscriptions[i]() == function
+                    ):
                         torm.append(i)
                 for i in torm:
                     allSubscriptions.pop(i)
@@ -445,7 +327,7 @@ class Connection():
             if self.connection:
                 self.connection.unsubscribe(topic)
 
-    def configureAlert(self, *a):
+    def configure_alert(self, *a):
         pass
 
     def _mqttSubscribe(topic, qos):
@@ -499,37 +381,42 @@ class Connection():
             with self.lock:
                 self.connection.subscribe(topic, qos)
 
-        if encoding == 'json':
+        if encoding == "json":
+
             def wrapper(t, m):
                 # Get rid of the extra kaithem framing part of the topic
                 t = t[len(self.busPrefix + "/in/"):]
                 if not isinstance(m, str):
-                    m = m.decode('utf-8')
+                    m = m.decode("utf-8")
                 try:
                     m = json.loads(m)
-                except:
+                except Exception:
                     logging.debug("Bad JSON:" + m[:64])
                 function()(t, m)
 
-        elif encoding == 'msgpack':
+        elif encoding == "msgpack":
+
             def wrapper(t, m):
                 # Get rid of the extra kaithem framing part of the topic
                 t = t[len(self.busPrefix + "/in/"):]
                 function()(t, msgpack.unpackb(m, raw=False))
 
-        elif encoding == 'utf8':
+        elif encoding == "utf8":
+
             def wrapper(t, m):
                 # Get rid of the extra kaithem framing part of the topic
                 t = t[len(self.busPrefix + "/in/"):]
                 if not isinstance(m, str):
-                    m = m.decode('utf-8')
+                    m = m.decode("utf-8")
                 function()(t, m)
 
-        elif encoding == 'raw':
+        elif encoding == "raw":
+
             def wrapper(t, m):
                 # Get rid of the extra kaithem framing part of the topic
                 t = t[len(self.busPrefix + "/in/"):]
                 function()(t, m)
+
         else:
             raise ValueError("Invalid encoding: " + encoding)
 
@@ -541,7 +428,7 @@ class Connection():
         # Extra data is mostly used for unsubscription
         self.subscribeWrappers[x] = (function, wrapper, topic, internalTopic)
 
-        logging.debug("MQTT subscribe to " + topic + " at " + self.server)
+        # logging.debug("MQTT subscribe to " + topic + " at " + self.server)
         # Ref to f exists as long as the original does because it's kept in subscribeWrappers
         messagebus.subscribe(internalTopic, wrapper)
 
@@ -552,21 +439,31 @@ class Connection():
             workers.do(backgroundSubscribeTask)
 
     def publish(self, topic, message, qos=2, encoding="json", retain=False):
-        if encoding == 'json':
+        if encoding == "json":
             message = json.dumps(message)
-        elif encoding == 'msgpack':
+        elif encoding == "msgpack":
             message = msgpack.packb(message, use_bin_type=True)
-        elif encoding == 'utf8':
+        elif encoding == "utf8":
             message = message.encode("utf8")
-        elif encoding == 'raw':
+        elif encoding == "raw":
             pass
         else:
             raise ValueError("Invalid encoding!")
-        messagebus.postMessage(self.busPrefix + "/out/" +
-                               topic, message, annotation=(qos, retain))
+        messagebus.post_message(
+            self.busPrefix + "/out/" + topic, message, annotation=(qos, retain)
+        )
 
 
-def getConnection(server, port=1883, password=None, messageBusName=None, *, alertPriority="info", alertAck=True, connectionID=''):
+def get_connection(
+    server,
+    port=1883,
+    password=None,
+    message_bus_name=None,
+    *,
+    alert_priority="info",
+    alert_ack=True,
+    connection_id=""
+):
     # Kaithem is gonna monkeypatch kaithem with one that has better
     # logging
     global Connection
@@ -576,27 +473,38 @@ def getConnection(server, port=1883, password=None, messageBusName=None, *, aler
     with lock:
         x = None
 
-        connectionIDSuffix = ''
-        if connectionID:
-            connectionIDSuffix = '?' + connectionID
+        connection_idSuffix = ""
+        if connection_id:
+            connection_idSuffix = "?" + connection_id
 
-        if server + ":" + str(port) + connectionIDSuffix in connections:
-            x = connections[server + ":" + str(port) + connectionIDSuffix]()
+        if server + ":" + str(port) + connection_idSuffix in connections:
+            x = connections[server + ":" + str(port) + connection_idSuffix]()
 
         if x:
-            if not messageBusName == x.messageBusName:
-               # We can safely use the existing one.   If t
+            if not message_bus_name == x.message_bus_name:
+                # We can safely use the existing one.   If t
                 logging.warning(
-                    "Using connection that already exists, but with a different message bus name:  " + x.messageBusName)
+                    "Using connection that already exists, but with a different message bus name:  "
+                    + x.message_bus_name
+                )
 
-                messageBusName = x.messageBusName
+                message_bus_name = x.message_bus_name
 
             if x.password or password:
                 if not x.password == password:
                     raise ValueError(
-                        "There is already a connection to the same host and user, but with a different password.")
+                        "There is already a connection to the same host and user, but with a different password."
+                    )
 
-            x.configureAlert(alertPriority, alertAck)
+            x.configure_alert(alert_priority, alert_ack)
             return x
 
-        return Connection(server, port, password=password, alertAck=True, alertPriority="info", messageBusName=messageBusName, connectionID=connectionID)
+        return Connection(
+            server,
+            port,
+            password=password,
+            alert_ack=True,
+            alert_priority="info",
+            message_bus_name=message_bus_name,
+            connection_id=connection_id,
+        )
